@@ -140,9 +140,6 @@ func excludeFunc(excludePaths []string) func(results scan.Results) scan.Results
 	return func(results scan.Results) scan.Results {
 		for i, result := range results {
 			rng := result.Range()
-			if rng == nil {
-				continue
-			}
 			for _, exclude := range excludePaths {
 				exclude = fmt.Sprintf("%c%s%[1]c", filepath.Separator, filepath.Clean(exclude))
 				if strings.Contains(
@@ -172,7 +169,7 @@ func configureOptions(cmd *cobra.Command, fsRoot, dir string) ([]options.Scanner
 		scanner.ScannerWithAlternativeIDProvider(legacy.FindIDs),
 		options.ScannerWithPolicyNamespaces("custom"),
 		scanner.ScannerWithDownloadsAllowed(!noModuleDownloads),
-		scanner.ScannerWithRegoOnly(regoOnly),
+		options.ScannerWithRegoOnly(regoOnly),
 		options.ScannerWithEmbeddedPolicies(true),
 	)
 
@@ -288,8 +285,8 @@ func applyConfigFiles(options []options.ScannerOption, dir string) ([]options.Sc
 			if len(conf.IncludedChecks) > 0 {
 				options = append(options, scanner.ScannerWithIncludedRules(conf.IncludedChecks))
 			}
-			if len(conf.ExcludedChecks) > 0 {
-				options = append(options, scanner.ScannerWithExcludedRules(append(conf.ExcludedChecks, excludedRuleIDs)))
+			if len(conf.GetValidExcludedChecks()) > 0 {
+				options = append(options, scanner.ScannerWithExcludedRules(append(conf.GetValidExcludedChecks(), excludedRuleIDs)))
 			}
 			if len(conf.ExcludeIgnores) > 0 {
 				options = append(options, scanner.ScannerWithExcludeIgnores(append(conf.ExcludeIgnores, excludeIgnoresIDs)))
