@@ -7,6 +7,7 @@ import (
 	"os"
 	"path/filepath"
 	"strings"
+	"time"
 
 	"github.com/aquasecurity/defsec/pkg/severity"
 	"gopkg.in/yaml.v2"
@@ -54,6 +55,25 @@ func LoadConfig(configFilePath string) (*Config, error) {
 	return config, nil
 }
 
+func (c *Config) GetValidExcludedChecks() (excludedChecks []string) {
+	for _, check := range c.ExcludedChecks {
+		if strings.Contains(check, ":") {
+			parts := strings.Split(check, ":")
+			if len(parts) == 2 {
+				if expiry, err := time.Parse("2006-01-02", parts[1]); err == nil {
+					if expiry.Before(time.Now()) {
+						continue
+					}
+				}
+			}
+			excludedChecks = append(excludedChecks, parts[0])
+		} else {
+			excludedChecks = append(excludedChecks, check)
+		}
+	}
+	return excludedChecks
+}
+
 func rewriteSeverityOverrides(config *Config) {
 	for k, s := range config.SeverityOverrides {
 		config.SeverityOverrides[k] = string(severity.StringToSeverity(s))
